function [coop_1, coop_2, s_1, s_2] = strg_choice_2(strg_1, strg_2, beta, no_rounds)

% Based on strg_choice.m but adapted for the simulation looking at whether
% it might look like subjects are using memory 1 strategies when in fact
% they are using > memory 1.

% strg_choice generates choices for strategy pair strg_1, strg_2, with an
% implementation error of beta for no_rounds
% The choices are two column vectors coop_1 and coop_2
% Strategies are coded as:
%   -   AD = 1, AC = 2, Grim = 3, TFT = 4, STFT = 5, WSLS = 6, T2 = 7
%   -   FRD (2012) AER strategies with more than 2 states: TF2T, TF3T,
%       2TFT, 2TF2T, Grim2, Grim3.
% it also produces matrices of what each strategy prescribes for players 1
% and 2: s_1 and s_2.

% initialize variables
coop_1 = -ones(no_rounds,1);
coop_2 = -ones(no_rounds,1);
s_1 = -ones(no_rounds, 13 );       % 7 + 6 strategies; class 1 and 4
s_2 = -ones(no_rounds, 13 );
epsilon = rand(no_rounds,2);
s1_1_m1 = -ones( no_rounds-1 , 7 );   % class 1 up to to the previous round
s1_2_m1 = -ones( no_rounds-1 , 7 );   % class 1 up to to the previous round
s4_1_m1 = -ones( no_rounds-1 , 6 );   % class 4 up to to the previous round
s4_2_m1 = -ones( no_rounds-1 , 6 );   % class 4 up to to the previous round


% choices in round 1
s_1 = [strg([], [], [], 1, 1), strg([], [], [], 1, 4)];
s_2 = s_1;
coop_1(1,1) = ( s_1(1,strg_1)*(epsilon(1,1)<=beta) ) + ( (1-s_1(1,strg_1))*(epsilon(1,1)>beta) );
coop_2(1,1) = ( s_2(1,strg_2)*(epsilon(1,2)<=beta) ) + ( (1-s_2(1,strg_2))*(epsilon(1,2)>beta) );
% choices in rounds > 1
j = 2;
while j <= no_rounds    
    s1_1_m1 = s_1(1:(j-1),1:7);
    s4_1_m1 = s_1(1:(j-1),8:13);
    s1_2_m1 = s_2(1:(j-1),1:7);
    s4_2_m1 = s_2(1:(j-1),8:13);
    s_1(1:j,:) = [strg(coop_1, coop_2, s1_1_m1, j, 1), strg(coop_1, coop_2, s4_1_m1, j, 4)];
    s_2(1:j,:) = [strg(coop_2, coop_1, s1_2_m1, j, 1), strg(coop_2, coop_1, s4_2_m1, j, 4)];
    coop_1(j,1) = ( s_1(j,strg_1)*(epsilon(j,1)<=beta) ) + ( (1-s_1(j,strg_1))*(epsilon(j,1)>beta) );
    coop_2(j,1) = ( s_2(j,strg_2)*(epsilon(j,2)<=beta) ) + ( (1-s_2(j,strg_2))*(epsilon(j,2)>beta) );
    j = j + 1;    
end

% Change log
% 07/07/16:
%   - Created based on strg_choice.m but only includes classes 1 and 4.