function [waldstat, waldprb] = wald_plus(theta_M,R,q_V,vc)

% wald_plus is similar to waldtest but it is adapted for df_strat where we
% elicit strategies.
% Inputs are as in waldtest but _M indicates a matrix and _V indicates a 
% vector or matrix, they are the matrix and vector of stored values from 
% the bootstrap and q_V is obtained from data

%R
%size(q_V)

% This is the case where the hypothesis is that a specific phi (estimated 
% proportion of a strategy) equals its corresponding elicited probability
if length(q_V) == 1

foo = [];
for i = 1:length(q_V)
    [bar, baz] = waldtest_gf(theta_M(:,i),R,q_V(i,1),vc);
    foo(i,1) = bar;
    i = i+1;
end


% This is the case where the hypothesis is that multiple phis (estimated 
% proportion of a strategy) equal their corresponding elicited
% probabilities
else
    
foo = [];
for i = 1:length(q_V)
    if size(R, 1) == 1
        qux = q_V(i,:)';
        quuux = theta_M;
        RR = R;
        vcvc = vc;
    else
        if size(R, 2) ~= size(q_V, 2) + 1
           disp('There is a problem of matrix dimension');
           return
        else
            % The first element of x_M is alpha (not phi); phi_1 is the
            % second element; so the first constraint is 0*estimates = 0.
            % We could also have truncated x_M or added the 0 before
            % imputing the values into wald_plus
            quux = [0, q_V(i,:)]';
            quuux = theta_M([2:end],:);
            RR = eye(length(vc)-1);
            qux = quux(2:end);
            vcvc = vc([2:end],[2:end]);
        end
    end
    [bar, baz] = waldtest_gf(quuux(:,i),RR,qux,vcvc);
    foo(i,1) = bar;
    i = i+1;
end

end

waldstat = mean(foo);

[dof,k]=size(R);
waldprb = chis_prb_gf(waldstat,dof);
